import axios from 'axios';
import type {
  OrgTreeItem,
  OrgItem,
  EnableOrgData,
  UserListFilter,
  UserListPageParams,
  UserListPageRes,
  UserUpdateParams,
  RoleItem,
  RoleListPageParams,
  RoleListPageRes,
  RoleUpdateParams,
  PrivilegeTreeItem,
  RoleBoundPrivilegesRes,
  ExamRuleDetailRes,
  CardRuleListPageParams,
  CardRuleListPageRes,
  CardRuleItem,
  SaveCardRuleParams,
  EnumItem,
  CardListParams,
  CardListPageRes,
  PrintTemplateListParams,
  PrintTemplateListRes,
  PrintTemplateItem,
  AttachmentItem,
} from './types/base';
import { AbleParams } from './types/common';

// common
export const getEnums = (type: string): Promise<EnumItem[]> => {
  return axios.post('/api/admin/common/get_enums', {}, { params: { type } });
};
export const attachmentDetail = (id: string): Promise<AttachmentItem> => {
  return axios.post('/api/admin/common/file/get_one', {}, { params: { id } });
};

// user-manage
export function userListPage(
  params: UserListPageParams
): Promise<UserListPageRes> {
  return axios.post('/api/admin/sys/user/list', {}, { params });
}
export function updateUser(datas: UserUpdateParams): Promise<boolean> {
  return axios.post('/api/admin/sys/user/save', datas);
}
export function ableUser(params: AbleParams): Promise<boolean> {
  return axios.post('/api/admin/sys/user/enable', params);
}
export function deleteUser(id: string): Promise<boolean> {
  return axios.post('/api/admin/sys/user/remove', {}, { params: { id } });
}
export function resetPwd(id: string): Promise<boolean> {
  return axios.post(
    '/api/admin/sys/user/reset_password',
    {},
    { params: { id } }
  );
}
export function userRoleListPage(): Promise<RoleItem[]> {
  return axios.post('/api/admin/sys/role/list_to_user', {});
}

export function exportUser(params: UserListFilter): Promise<Blob> {
  return axios.post(
    '/api/admin/sys/user/export',
    {},
    {
      params,
      responseType: 'blob',
    }
  );
}

// role-manage
export function roleListPage(
  params: RoleListPageParams
): Promise<RoleListPageRes> {
  return axios.post('/api/admin/sys/role/list', {}, { params });
}
export function ableRole(params: AbleParams): Promise<boolean> {
  return axios.post('/api/admin/sys/role/enable', params);
}
export function updateRole(datas: RoleUpdateParams): Promise<boolean> {
  return axios.post('/api/admin/sys/role/save', datas);
}
export function deleteRole(id: string): Promise<boolean> {
  return axios.post('/api/admin/sys/role/remove', {}, { params: { id } });
}
export function userBoundRoles(userId: string): Promise<boolean> {
  return axios.post(
    '/api/admin/sys/role/get_user_roles',
    {},
    { params: { userId } }
  );
}
// role-menu-manage
export function privilegeList(): Promise<PrivilegeTreeItem[]> {
  return axios.post('/api/admin/sys/privilege/list', {});
}
export function roleBoundPrivileges(
  roleId: string
): Promise<RoleBoundPrivilegesRes> {
  return axios.post(
    '/api/admin/sys/privilege/get_role_privileges',
    {},
    { params: { roleId } }
  );
}
// role-user-manage
export function roleGroupList(params) {
  return axios.post('/api/admin/sys/role/group/list', {}, { params });
}
export function updateRoleGroup(datas) {
  return axios.post('/api/admin/sys/role/group/save', datas);
}

// organization-manage
export function organizationList(): Promise<OrgTreeItem[]> {
  return axios.post('/api/admin/sys/org/list', {});
}
export function updateOrganization(datas: OrgItem): Promise<boolean> {
  return axios.post('/api/admin/sys/org/save', datas);
}
export function ableOrganization(datas: EnableOrgData): Promise<boolean> {
  return axios.post('/api/admin/sys/org/enable', datas);
}
export function deleteOrganization(id: string): Promise<boolean> {
  return axios.post('/api/admin/sys/org/remove', { id });
}

// common-rule
export function examRuleDetail(): Promise<ExamRuleDetailRes> {
  return axios.post('/api/admin/basic/exam_rule/list', {});
}
export function saveExamRule(datas: ExamRuleDetailRes): Promise<number> {
  return axios.post('/api/admin/basic/exam_rule/save', datas);
}

// card-rule
export function cardRuleListPage(
  params: CardRuleListPageParams
): Promise<CardRuleListPageRes> {
  return axios.post('/api/admin/basic/card_rule/list', {}, { params });
}
export function cardRuleQuery(): Promise<CardRuleItem[]> {
  return axios.post('/api/admin/basic/card_rule/query', {});
}
export function cardRuleDetail(id: string): Promise<boolean> {
  return axios.post('/api/admin/basic/card_rule/get_one', { params: { id } });
}
export function saveCardRule(datas: SaveCardRuleParams): Promise<boolean> {
  return axios.post('/api/admin/basic/card_rule/save', datas);
}
export function ableCardRule(params: AbleParams): Promise<boolean> {
  return axios.post('/api/admin/basic/card_rule/enable', params);
}
export function deleteCardRule(id: string): Promise<boolean> {
  return axios.post('/api/admin/basic/card_rule/delete', { id });
}
// card-manage
export function cardListPage(params: CardListParams): Promise<CardListPageRes> {
  return axios.post('/api/admin/exam/card/page', {}, { params });
}
export function updateCard(datas) {
  return axios.post('/api/admin/exam/card/save_generic', datas);
}
export function deleteCard(id: string): Promise<boolean> {
  return axios.post(
    '/api/admin/exam/card/delete_generic',
    {},
    { params: { id } }
  );
}
export function convertCardImage(id: string): Promise<boolean> {
  return axios.post(
    '/api/admin/exam/card/convert_image',
    {},
    { params: { id } }
  );
}
export function downloadCardFile(id: string): Promise<Blob> {
  return axios.post(
    '/api/admin/exam/card/download_card',
    {},
    {
      responseType: 'blob',
      params: { id },
    }
  );
}

// print-template-manage
export const templateListPage = (
  params: PrintTemplateListParams
): Promise<PrintTemplateListRes> => {
  return axios.post('/api/admin/basic/template/list', {}, { params });
};
export const templateDetail = (id: string): Promise<PrintTemplateItem> => {
  return axios.post(
    '/api/admin/basic/template/get_one',
    {},
    { params: { id } }
  );
};
export const updateTemplate = (datas) => {
  return axios.post('/api/admin/basic/template/save', datas);
};
export const ableTemplate = (params: AbleParams): Promise<boolean> => {
  return axios.post('/api/admin/basic/template/enable', {}, { params });
};
export const deleteTemplate = (id: string): Promise<boolean> => {
  return axios.post('/api/admin/basic/template/remove', {}, { params: { id } });
};
export const templateContentView = (id: string): Promise<string> => {
  return axios.post(
    '/api/admin/basic/template/read_content',
    {},
    { params: { id } }
  );
};
