import axios from 'axios';
import type {
  OptionItem,
  TaskListPageRes,
  TaskItemDetail,
  TaskRuleUpdateParams,
  OrderRecordListPageRes,
  OrderRecordListPageParam,
} from './types/order';
import { AbleParams } from './types/common';

// common
export function taskQuery(): Promise<OptionItem[]> {
  return axios.post('/api/apply/task/list', {});
}
export function teachingQuery(): Promise<OptionItem[]> {
  return axios.post('/api/apply/teaching/list', {});
}
export function agentQuery(teachingId: string): Promise<OptionItem[]> {
  return axios.post(
    '/api/apply/agent/list',
    {},
    { params: { id: teachingId } }
  );
}

// task-manage
export function taskListPage(params: {
  name: string;
}): Promise<TaskListPageRes> {
  return axios.post('/api/admin/apply/task/page', {}, { params });
}
export function taskDetailInfo(id: string): Promise<TaskItemDetail> {
  return axios.post('/api/admin/apply/task/find', {}, { params: { id } });
}
export function updateTaskRule(
  datas: TaskRuleUpdateParams
): Promise<{ id: string }> {
  return axios.post('/api/admin/apply/task/rule/save', datas);
}
export function ableTask(params: AbleParams): Promise<boolean> {
  return axios.post('/api/admin/apply/task/enable', params);
}

// 预约名单
// 预约名单详情分页
export function orderRecordListPage(
  params: OrderRecordListPageParam
): Promise<OrderRecordListPageRes> {
  return axios.post('/api/apply/std/page', params);
}
// 预约名单详情-取消预约
export function orderRecordCancel(id: number): Promise<boolean> {
  return axios.post('/api/apply/std/cancel', {}, { params: { id } });
}
// 预约名单详情-一键自动分配
export function orderRecordAutoAssign(params: {
  taskId?: number;
}): Promise<boolean> {
  return axios.post('/api/apply/std/auto/assign', {}, { params });
}
// 预约名单详情-导入模板下载
export function orderRecordTemplate(): Promise<Blob> {
  return axios.post(
    '/api/apply/imp/template',
    {},
    {
      responseType: 'blob',
    }
  );
}
// 预约名单详情-打印签到表
export function orderRecordPrint(params: {
  teachingId?: number;
}): Promise<Blob> {
  return axios.post(
    '/api/apply/std/auto/sign/in/print',
    {},
    {
      responseType: 'blob',
      params,
    }
  );
}
