import {
  CARD_CREATE_METHOD_TYPE,
  CARD_TYPE,
  DATA_PRIVILEGE_TYPE,
  EXAM_NUMBER_STYLE,
  TEMPLATE_CLASSIFY,
} from '@/constants/enumerate';
import { PageResult, PageParams } from './common';
import { UserMenuItem } from './user';

export interface EnumItem {
  name: string;
  ordinal: number;
  code: string;
  desc: string;
  enable: boolean;
  disabled: boolean;
}
export interface AttachmentItem {
  id: string;
  createId: string;
  createTime: number;
  updateId: string | null;
  updateTime: number;
  name: string;
  path: string;
  type: string;
  size: number;
  md5: string;
}

export interface OrgItem {
  id: string;
  schoolId: string;
  code: string;
  name: string;
  parentId: string | null;
  enable: boolean;
  type: string;
}

export type OrgTreeItem = { children: OrgTreeItem[] } & OrgItem;

export type EnableOrgData = Pick<OrgItem, 'id' | 'enable'>;

export interface RoleItem {
  id: string;
  createId: string;
  createTime: number;
  updateId: string;
  updateTime: number;
  schoolId: string;
  orgId: string;
  name: string;
  enable: boolean;
  type: string;
  privilegeIds: string;
  defaultRole: boolean;
  source: string;
  interpret: boolean;
}

export interface UserItem {
  id: string;
  schoolId: string;
  loginName: string;
  realName: string;
  mobileNumber: string;
  enable: boolean;
  remark: string;
  orgId: string;
  orgName: string;
  code: string;
  allowManualCard: boolean;
  roles: RoleItem[];
}

export type UserListPageRes = PageResult<UserItem>;

export interface UserListFilter {
  orgId: string;
  userInfo: string;
  roleId: string;
  enable: boolean;
}
export type UserListPageParams = PageParams<UserListFilter>;

export interface UserUpdateParams {
  id?: string;
  loginName: string;
  realName: string;
  //   code: "",
  mobileNumber: string;
  allowManualCard: number;
  roleIds: string[];
  courseIds: string[];
  orgId: string[];
}

export type RoleListPageParams = PageParams<{
  name: string;
}>;
export type RoleListPageRes = PageResult<RoleItem>;

export type DataPermissionTypeEnum = keyof typeof DATA_PRIVILEGE_TYPE;

export interface RoleUpdateParams {
  id?: string;
  name: string;
  interpret: string;
  dataPermissionType: DataPermissionTypeEnum;
  privilegeIds: string[];
  defaultRole: boolean;
}

export type PrivilegeTreeItem = {
  children: PrivilegeTreeItem[];
} & UserMenuItem;

export interface RoleBoundPrivilegesRes {
  id: string;
  name: string;
  privilegeIds: string[];
  dataPermissionInfo: Array<{
    privilegeId: string;
    dataPermissionType: DataPermissionTypeEnum;
  }>;
  defaultPrivilegeIds: string[];
  defaultRole: boolean;
  interpret: string;
}

export interface ExamRuleItem {
  name: string;
  code: string;
  enable: boolean;
  disabled?: boolean;
  rate?: number;
  ordinal?: number;
}

export interface SignScope {
  basic: ExamRuleItem[];
  table: ExamRuleItem[];
}
export interface PackageScope {
  title: ExamRuleItem[];
  basic: ExamRuleItem[];
}
export interface ExamRuleDetailRes {
  id: string;
  createId: string;
  createTime: number;
  updateId: string;
  updateTime: number;
  schoolId: string;
  orgId: string;
  requiredFields: string;
  extendFields: string;
  signScope: string;
  packageScope: string;
}

export interface CardRuleListFilter {
  enable: boolean;
  name: string;
  createStartTime: number;
  createEndTime: number;
}
export type CardRuleListPageParams = PageParams<CardRuleListFilter>;

export type ExamNumberStyleType = keyof typeof EXAM_NUMBER_STYLE;

export interface CardRuleItem {
  id: string;
  createId: string;
  createTime: number;
  updateId: string;
  updateTime: number;
  schoolId: string;
  orgId: string;
  name: string;
  examNumberStyle: ExamNumberStyleType;
  examNumberDigit: number;
  paperType: string;
  examAbsent: boolean;
  writeSign: boolean;
  discipline: boolean;
  undertakingEnable: boolean;
  undertakingBody: string;
  requiredFields: string;
  extendFields: string;
  titleRule: string;
  attention: string;
  objectiveAttention: string;
  subjectiveAttention: string;
  enable: boolean;
  remark: string;
  fillNumber: null;
  orgIds: null;
}
export type CardRuleListPageRes = PageResult<CardRuleItem>;

export interface SaveCardRuleParams {
  id: string | null;
  name: string;
  remark: string;
  examNumberStyle: string;
  examNumberDigit: number;
  paperType: string;
  examAbsent: boolean;
  discipline: boolean;
  writeSign: boolean;
  requiredFields: string;
  extendFields: string;
  titleRule: string;
  attention: string;
  objectiveAttention: string;
  subjectiveAttention: string;
}

export interface CardRuleType extends SaveCardRuleParams {
  requiredFields: ExamRuleItem[];
  extendFields: ExamRuleItem[];
}

export interface CardListFilter {
  title: string;
  cardType: string;
  createMethod: string;
  createStartTime: number;
  createEndTime: number;
}
export type CardListParams = PageParams<CardListFilter>;

export type CardType = keyof typeof CARD_TYPE;
export type CardCreateMethodType = keyof typeof CARD_CREATE_METHOD_TYPE;

export interface CardItem {
  id: string;
  createId: string;
  createTime: number;
  updateId: string;
  updateTime: number;
  schoolId: string;
  orgId: string;
  courseCode: string;
  courseName: string;
  title: string;
  makeMethod: string;
  status: 'SUBMIT' | 'STAGE';
  type: CardType;
  createMethod: CardCreateMethodType;
  attachmentId: string;
  enable: boolean;
  used: boolean;
  remark: string;
  cardRuleId: string;
  content: string;
  stageContent: string | null;
  htmlContent: string | null;
  backupAttachment: string | null;
  jpgAttachment: string;
  imageUrls: string[];
}
export type CardListPageRes = PageResult<CardItem>;

export interface PrintTemplateListFilter {
  enable: boolean | null;
  name: string;
  startTime: number;
  endTime: number;
}
export type PrintTemplateListParams = PageParams<PrintTemplateListFilter>;

export type TemplateClassifyType = keyof typeof TEMPLATE_CLASSIFY;
export interface PrintTemplateItem {
  id: string;
  createId: string;
  createTime: number;
  updateId: string;
  updateTime: number | null;
  schoolId: string;
  orgId: string | null;
  name: string;
  classify: TemplateClassifyType;
  displayRange: string | null;
  previewPath: string | null;
  attachmentId: string | null;
  enable: boolean;
  diallel: boolean;
  addBlankPage: boolean;
  lineHeightTimes: number;
  fontSize: string;
  textDesc: string | null;
  remark: string | null;
  orgIds: string | null;
  url: string | null;
}
export type PrintTemplateListRes = PageResult<PrintTemplateItem>;
