import { useAppStore } from '@/store';
import { reactive } from 'vue';
import { useRoute } from 'vue-router';

export default function usePermission() {
  const appStore = useAppStore();
  const route = useRoute();
  const permissions = reactive<Record<string, boolean>>({});

  function checkPrivilege(type, field, routeAlias = null) {
    const routerName = routeAlias || route.name;
    const keys = field
      .split(',')
      .map((item) => `${type}_${item}`.toLowerCase());

    return keys.some((key) => appStore.privilegeMap[routerName].includes(key));
  }

  function updatePermission() {
    const validKeys = appStore.privilegeMap[route.name];

    validKeys.forEach((key) => {
      permissions[key] = true;
    });
  }
  updatePermission();

  return {
    checkPrivilege,
    updatePermission,
    permissions,
  };
}

/*
v-if="permissions.condition_condition"
v-if="permissions.button_select"
v-if="permissions.button_add"
v-if="permissions.button_export"
v-if="permissions.button_import"
v-if="permissions.link_preview"
v-if="permissions.link_edit"
v-if="permissions.link_delete"
v-if="permissions.link_enable"
 */
